Range-v3: ranges::v3::partial_sort_copy_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::partial_sort_copy_fn Struct Reference
Algorithms

## Public Member Functions
template<typename I , typename SI , typename O , typename SO , typename C = ordered_less, typename PI = ident, typename PO = ident, requires = (PartialSortCopyConcept<I, O, C, PI, PO>() && Sentinel<SI, I>() && Sentinel<SO, O>())>
O | operator() (I begin, SI end, O out_begin, SO out_end, C pred=C{}, PI in_proj=PI{}, PO out_proj=PO{}) const
template<typename InRng , typename OutRng , typename C = ordered_less, typename PI = ident, typename PO = ident, typename I = iterator_t<InRng>, typename O = iterator_t<OutRng>, requires = (PartialSortCopyConcept<I, O, C, PI, PO>() && Range<InRng>() && Range<OutRng>())>
safe_iterator_t< OutRng > | operator() (InRng &&in_rng, OutRng &&out_rng, C pred=C{}, PI in_proj=PI{}, PO out_proj=PO{}) const